abacusai.edit_image_models — AbacusAI documentation

# abacusai.edit_image_models

## Classes

`EditImageModels` | Edit image models

## Module Contents

class abacusai.edit_image_models.EditImageModels(client, models=None, default=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Edit image models

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - models (list) – The models available for edit image.

    - default (str) – The default model for edit image.

  models = None
  default = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict